@@ -1,13 +1,19 @@
+# Entities (Dto)
+from .api_dto import ApiDto
 from .plot import Plot
 from .mlmodel import MLModel
 from .request import Request
 from .execution import Execution
 from .experiment import Experiment
-from .dsapi_json_encoder import DSAPIEncoder
 from .ds_dataframe import DSDataFrame
-from .dataframe_toolkit import DataFrameToolkit
-from .model_toolkit import ModelToolkit
 from .script import Script
-from .api_dto import ApiDto
+
+# Api
+from .wizata_dsapi_client import api
 from .wizata_dsapi_client import WizataDSAPIClient
+from .dataframe_toolkit import df_to_json, df_to_csv, df_from_json, df_from_csv
+from .model_toolkit import predict
+
+# Legacy
+from .dsapi_json_encoder import DSAPIEncoder
 from .wizard_function import WizardStep, WizardFunction
