@@ -2,28 +2,26 @@ import datetime
 import json
 import uuid
 import sys
-
 import dill
 import requests
 import pickle
 import pandas
-
+import plotly
+import msal
+import os
 import types
-
 import sklearn
 import wizata_dsapi
 
+
 from .plot import Plot
 from .request import Request
 from .mlmodel import MLModel
 from .experiment import Experiment
 from .script import Script
 from .execution import Execution
-from .dataframe_toolkit import DataFrameToolkit
 from .dsapi_json_encoder import DSAPIEncoder
 from .ds_dataframe import DSDataFrame
-import msal
-import os
 
 
 class WizataDSAPIClient:
@@ -413,8 +411,6 @@ class WizataDSAPIClient:
 
         return self.get(request)
 
-
-
     def execute(self,
                 execution: Execution = None,
                 request: Request = None,
@@ -490,6 +486,8 @@ class WizataDSAPIClient:
                         execution.models.append(self.get(MLModel(model_id=mlmodel["id"])))
                 if "resultDataframe" in obj.keys() and obj["resultDataframe"]["id"] is not None:
                     execution.output_ds_dataframe = self.get(DSDataFrame(df_id=obj["resultDataframe"]["id"]))
+                if "anomaliesList" in obj.keys() and isinstance(obj["anomaliesList"], str):
+                    execution.anomalies = json.loads(execution["anomaliesList"])
                 return execution
             else:
                 raise self.__raise_error(response)
@@ -608,3 +606,51 @@ class WizataDSAPIClient:
                 raise self.__raise_error(response)
         else:
             raise TypeError("Type not supported.")
+
+    def plot(self, plot_id: str = None, plot: wizata_dsapi = None, figure=None,):
+        """
+        Fetch and show plot.
+        :param plot: Wizata Plot Object
+        :param figure: JSON Figure
+        :param plot_id: Plot Id
+        :return:
+        """
+        if plot is not None and plot.figure is not None:
+            return plotly.io.from_json(plot.figure)
+        elif plot is not None and plot.figure is None:
+            plot = self.get(plot)
+            if plot.figure is not None:
+                return plotly.io.from_json(plot.figure)
+            else:
+                raise ValueError('No plot has been fetch.')
+        elif figure is not None:
+            return plotly.io.from_json(plot.figure)
+        elif id is not None:
+            plot = self.get(wizata_dsapi.Plot(plot_id=plot_id))
+            if plot.figure is not None:
+                return plotly.io.from_json(plot.figure)
+            else:
+                raise ValueError('No plot has been fetch.')
+        else:
+            raise KeyError('No valid arguments.')
+
+
+def api() -> WizataDSAPIClient:
+    """
+    Create a WizataDSAPIClient from environment variables.
+    :return: client
+    """
+    protocol = 'https'
+
+    if os.environ.get('WIZATA_PROTOCOL') is not None:
+        protocol = os.environ.get('WIZATA_PROTOCOL')
+
+    return WizataDSAPIClient(
+        tenant_id=os.environ.get('WIZATA_TENANT_ID'),
+        client_id=os.environ.get('WIZATA_CLIENT_ID'),
+        scope=os.environ.get('WIZATA_SCOPE'),
+        username=os.environ.get('WIZATA_USERNAME'),
+        password=os.environ.get('WIZATA_PASSWORD'),
+        domain=os.environ.get('WIZATA_DOMAIN'),
+        protocol=protocol
+    )
